gchecky.tools.encoder

Package gchecky :: Module tools :: Class encoder |
[hide private]
[frames] | no frames]

# Class encoder

source code

Instance Methods | [hide private]
serialize(self, data, xml_node) | source code
_create_element(self, tag) | source code
_create_text(self, value) | source code
_encode(self, data, node) @param node Is either a string or an XML node. | source code
__mark(self, obj) | source code
__unmark(self, obj) | source code

Class Methods | [hide private]
_encode_tag(clazz, tag) | source code
_escape_string(clazz, str) | source code

Method Details | [hide private]

### _encode(self, data, node) | source code
    @param node Is either a string or an XML node. If its a string then
                a node with such a name should be created, otherwise
                the existing xml node should be populated.